.. _capi-frame:

Function manipulating ``CHFL_FRAME``
------------------------------------

.. doxygentypedef:: CHFL_FRAME

.. doxygenfunction:: chfl_frame

.. doxygenfunction:: chfl_frame_copy

.. doxygenfunction:: chfl_frame_atoms_count

.. doxygenfunction:: chfl_frame_resize

.. doxygenfunction:: chfl_frame_add_atom

.. doxygenfunction:: chfl_frame_remove

.. doxygenfunction:: chfl_frame_positions

.. doxygenfunction:: chfl_frame_velocities

.. doxygenfunction:: chfl_frame_has_velocities

.. doxygenfunction:: chfl_frame_add_velocities

.. doxygenfunction:: chfl_frame_set_cell

.. doxygenfunction:: chfl_frame_set_topology

.. doxygenfunction:: chfl_frame_add_bond

.. doxygenfunction:: chfl_frame_remove_bond

.. doxygenfunction:: chfl_frame_add_residue

.. doxygenfunction:: chfl_frame_step

.. doxygenfunction:: chfl_frame_set_step

.. doxygenfunction:: chfl_frame_guess_topology

.. doxygenfunction:: chfl_frame_distance

.. doxygenfunction:: chfl_frame_angle

.. doxygenfunction:: chfl_frame_dihedral

.. doxygenfunction:: chfl_frame_out_of_plane

.. doxygenfunction:: chfl_frame_set_property

.. doxygenfunction:: chfl_frame_get_property

.. doxygenfunction:: chfl_frame_free
